pitchtools.named_chromatic_pitches_to_inversion_equivalent_chromatic_interval_class_number_dictionary
=====================================================================================================

.. autofunction:: abjad.tools.pitchtools.named_chromatic_pitches_to_inversion_equivalent_chromatic_interval_class_number_dictionary.named_chromatic_pitches_to_inversion_equivalent_chromatic_interval_class_number_dictionary
